Class: Google::Apis::JobsV4::Location
- Inherits:
-
Object
- Object
- Google::Apis::JobsV4::Location
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/jobs_v4/classes.rb,
lib/google/apis/jobs_v4/representations.rb,
lib/google/apis/jobs_v4/representations.rb
Overview
A resource that represents a location with full geographic information.
Instance Attribute Summary collapse
-
#lat_lng ⇒ Google::Apis::JobsV4::LatLng
An object that represents a latitude/longitude pair.
-
#location_type ⇒ String
The type of a location, which corresponds to the address lines field of google.
-
#postal_address ⇒ Google::Apis::JobsV4::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#radius_miles ⇒ Float
Radius in miles of the job location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
1625 1626 1627 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lat_lng ⇒ Google::Apis::JobsV4::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
1592 1593 1594 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1592 def lat_lng @lat_lng end |
#location_type ⇒ String
The type of a location, which corresponds to the address lines field of google.
type.PostalAddress. For example, "Downtown, Atlanta, GA, USA" has a type of
LocationType.NEIGHBORHOOD, and "Kansas City, KS, USA" has a type of
LocationType.LOCALITY.
Corresponds to the JSON property locationType
1600 1601 1602 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1600 def location_type @location_type end |
#postal_address ⇒ Google::Apis::JobsV4::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property postalAddress
1615 1616 1617 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1615 def postal_address @postal_address end |
#radius_miles ⇒ Float
Radius in miles of the job location. This value is derived from the location
bounding box in which a circle with the specified radius centered from google.
type.LatLng covers the area associated with the job location. For example,
currently, "Mountain View, CA, USA" has a radius of 6.17 miles.
Corresponds to the JSON property radiusMiles
1623 1624 1625 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1623 def radius_miles @radius_miles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1630 1631 1632 1633 1634 1635 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1630 def update!(**args) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) @location_type = args[:location_type] if args.key?(:location_type) @postal_address = args[:postal_address] if args.key?(:postal_address) @radius_miles = args[:radius_miles] if args.key?(:radius_miles) end |