Class: Google::Apis::JobsV4::RequestMetadata
- Inherits:
-
Object
- Object
- Google::Apis::JobsV4::RequestMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/jobs_v4/classes.rb,
lib/google/apis/jobs_v4/representations.rb,
lib/google/apis/jobs_v4/representations.rb
Overview
Meta information related to the job searcher or entity conducting the job search. This information is used to improve the performance of the service.
Instance Attribute Summary collapse
-
#allow_missing_ids ⇒ Boolean
(also: #allow_missing_ids?)
Only set when any of domain, session_id and user_id isn't available for some reason.
-
#device_info ⇒ Google::Apis::JobsV4::DeviceInfo
Device information collected from the job seeker, candidate, or other entity conducting the job search.
-
#domain ⇒ String
Required if allow_missing_ids is unset or
false. -
#session_id ⇒ String
Required if allow_missing_ids is unset or
false. -
#user_id ⇒ String
Required if allow_missing_ids is unset or
false.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestMetadata
constructor
A new instance of RequestMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestMetadata
Returns a new instance of RequestMetadata.
2077 2078 2079 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing_ids ⇒ Boolean Also known as: allow_missing_ids?
Only set when any of domain, session_id and user_id isn't available for some
reason. It is highly recommended not to set this field and provide accurate
domain, session_id and user_id for the best service experience.
Corresponds to the JSON property allowMissingIds
2033 2034 2035 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2033 def allow_missing_ids @allow_missing_ids end |
#device_info ⇒ Google::Apis::JobsV4::DeviceInfo
Device information collected from the job seeker, candidate, or other entity
conducting the job search. Providing this information improves the quality of
the search results across devices.
Corresponds to the JSON property deviceInfo
2041 2042 2043 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2041 def device_info @device_info end |
#domain ⇒ String
Required if allow_missing_ids is unset or false. The client-defined scope or
source of the service call, which typically is the domain on which the service
has been implemented and is currently being run. For example, if the service
is being run by client Foo, Inc., on job board www.foo.com and career site
www.bar.com, then this field is set to "foo.com" for use on the job board, and
"bar.com" for use on the career site. Note that any improvements to the model
for a particular tenant site rely on this field being set correctly to a
unique domain. The maximum number of allowed characters is 255.
Corresponds to the JSON property domain
2053 2054 2055 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2053 def domain @domain end |
#session_id ⇒ String
Required if allow_missing_ids is unset or false. A unique session
identification string. A session is defined as the duration of an end user's
interaction with the service over a certain period. Obfuscate this field for
privacy concerns before providing it to the service. Note that any
improvements to the model for a particular tenant site rely on this field
being set correctly to a unique session ID. The maximum number of allowed
characters is 255.
Corresponds to the JSON property sessionId
2064 2065 2066 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2064 def session_id @session_id end |
#user_id ⇒ String
Required if allow_missing_ids is unset or false. A unique user
identification string, as determined by the client. To have the strongest
positive impact on search quality make sure the client-level is unique.
Obfuscate this field for privacy concerns before providing it to the service.
Note that any improvements to the model for a particular tenant site rely on
this field being set correctly to a unique user ID. The maximum number of
allowed characters is 255.
Corresponds to the JSON property userId
2075 2076 2077 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2075 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2082 2083 2084 2085 2086 2087 2088 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 2082 def update!(**args) @allow_missing_ids = args[:allow_missing_ids] if args.key?(:allow_missing_ids) @device_info = args[:device_info] if args.key?(:device_info) @domain = args[:domain] if args.key?(:domain) @session_id = args[:session_id] if args.key?(:session_id) @user_id = args[:user_id] if args.key?(:user_id) end |