Class: Google::Apis::JobsV4::SearchJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/jobs_v4/classes.rb,
lib/google/apis/jobs_v4/representations.rb,
lib/google/apis/jobs_v4/representations.rb

Overview

Response for SearchJob method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchJobsResponse

Returns a new instance of SearchJobsResponse.



2397
2398
2399
# File 'lib/google/apis/jobs_v4/classes.rb', line 2397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#broadened_query_jobs_countFixnum

If query broadening is enabled, we may append additional results from the broadened query. This number indicates how many of the jobs returned in the jobs field are from the broadened query. These results are always at the end of the jobs list. In particular, a value of 0, or if the field isn't set, all the jobs in the jobs list are from the original (without broadening) query. If this field is non-zero, subsequent requests with offset after this result set should contain all broadened results. Corresponds to the JSON property broadenedQueryJobsCount

Returns:

  • (Fixnum)


2355
2356
2357
# File 'lib/google/apis/jobs_v4/classes.rb', line 2355

def broadened_query_jobs_count
  @broadened_query_jobs_count
end

#histogram_query_resultsArray<Google::Apis::JobsV4::HistogramQueryResult>

The histogram results that match with specified SearchJobsRequest. histogram_queries. Corresponds to the JSON property histogramQueryResults



2361
2362
2363
# File 'lib/google/apis/jobs_v4/classes.rb', line 2361

def histogram_query_results
  @histogram_query_results
end

#location_filtersArray<Google::Apis::JobsV4::Location>

The location filters that the service applied to the specified query. If any filters are lat-lng based, the Location.location_type is Location.LocationType. LOCATION_TYPE_UNSPECIFIED. Corresponds to the JSON property locationFilters

Returns:



2368
2369
2370
# File 'lib/google/apis/jobs_v4/classes.rb', line 2368

def location_filters
  @location_filters
end

#matching_jobsArray<Google::Apis::JobsV4::MatchingJob>

The Job entities that match the specified SearchJobsRequest. Corresponds to the JSON property matchingJobs



2373
2374
2375
# File 'lib/google/apis/jobs_v4/classes.rb', line 2373

def matching_jobs
  @matching_jobs
end

#metadataGoogle::Apis::JobsV4::ResponseMetadata

Additional information returned to client, such as debugging information. Corresponds to the JSON property metadata



2378
2379
2380
# File 'lib/google/apis/jobs_v4/classes.rb', line 2378

def 
  @metadata
end

#next_page_tokenString

The token that specifies the starting position of the next page of results. This field is empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2384
2385
2386
# File 'lib/google/apis/jobs_v4/classes.rb', line 2384

def next_page_token
  @next_page_token
end

#spell_correctionGoogle::Apis::JobsV4::SpellingCorrection

Spell check result. Corresponds to the JSON property spellCorrection



2389
2390
2391
# File 'lib/google/apis/jobs_v4/classes.rb', line 2389

def spell_correction
  @spell_correction
end

#total_sizeFixnum

Number of jobs that match the specified query. Note: This size is precise only if the total is less than 100,000. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


2395
2396
2397
# File 'lib/google/apis/jobs_v4/classes.rb', line 2395

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
# File 'lib/google/apis/jobs_v4/classes.rb', line 2402

def update!(**args)
  @broadened_query_jobs_count = args[:broadened_query_jobs_count] if args.key?(:broadened_query_jobs_count)
  @histogram_query_results = args[:histogram_query_results] if args.key?(:histogram_query_results)
  @location_filters = args[:location_filters] if args.key?(:location_filters)
  @matching_jobs = args[:matching_jobs] if args.key?(:matching_jobs)
  @metadata = args[:metadata] if args.key?(:metadata)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spell_correction = args[:spell_correction] if args.key?(:spell_correction)
  @total_size = args[:total_size] if args.key?(:total_size)
end