Class: Google::Apis::JobsV4::Tenant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/jobs_v4/classes.rb,
lib/google/apis/jobs_v4/representations.rb,
lib/google/apis/jobs_v4/representations.rb

Overview

A Tenant resource represents a tenant in the service. A tenant is a group or entity that shares common access with specific privileges for resources like jobs. Customer may create multiple tenants to provide data isolation for different groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Tenant

Returns a new instance of Tenant.



2509
2510
2511
# File 'lib/google/apis/jobs_v4/classes.rb', line 2509

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_idString

Required. Client side tenant identifier, used to uniquely identify the tenant. The maximum number of allowed characters is 255. Corresponds to the JSON property externalId

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/jobs_v4/classes.rb', line 2500

def external_id
  @external_id
end

#nameString

Required during tenant update. The resource name for a tenant. This is generated by the service when a tenant is created. The format is "projects/ project_id/tenants/tenant_id", for example, "projects/foo/tenants/bar". Corresponds to the JSON property name

Returns:

  • (String)


2507
2508
2509
# File 'lib/google/apis/jobs_v4/classes.rb', line 2507

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2514
2515
2516
2517
# File 'lib/google/apis/jobs_v4/classes.rb', line 2514

def update!(**args)
  @external_id = args[:external_id] if args.key?(:external_id)
  @name = args[:name] if args.key?(:name)
end