Class: Google::Apis::JobsV4::MatchingJob
- Inherits:
-
Object
- Object
- Google::Apis::JobsV4::MatchingJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/jobs_v4/classes.rb,
lib/google/apis/jobs_v4/representations.rb,
lib/google/apis/jobs_v4/representations.rb
Overview
Job entry with metadata inside SearchJobsResponse.
Instance Attribute Summary collapse
-
#commute_info ⇒ Google::Apis::JobsV4::CommuteInfo
Commute details related to this job.
-
#job ⇒ Google::Apis::JobsV4::Job
A Job resource represents a job posting (also referred to as a "job listing" or "job requisition").
-
#job_summary ⇒ String
A summary of the job with core information that's displayed on the search results listing page.
-
#job_title_snippet ⇒ String
Contains snippets of text from the Job.title field most closely matching a search query's keywords, if available.
-
#search_text_snippet ⇒ String
Contains snippets of text from the Job.description and similar fields that most closely match a search query's keywords, if available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MatchingJob
constructor
A new instance of MatchingJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MatchingJob
Returns a new instance of MatchingJob.
1746 1747 1748 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commute_info ⇒ Google::Apis::JobsV4::CommuteInfo
Commute details related to this job.
Corresponds to the JSON property commuteInfo
1716 1717 1718 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1716 def commute_info @commute_info end |
#job ⇒ Google::Apis::JobsV4::Job
A Job resource represents a job posting (also referred to as a "job listing"
or "job requisition"). A job belongs to a Company, which is the hiring entity
responsible for the job.
Corresponds to the JSON property job
1723 1724 1725 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1723 def job @job end |
#job_summary ⇒ String
A summary of the job with core information that's displayed on the search
results listing page.
Corresponds to the JSON property jobSummary
1729 1730 1731 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1729 def job_summary @job_summary end |
#job_title_snippet ⇒ String
Contains snippets of text from the Job.title field most closely matching a
search query's keywords, if available. The matching query keywords are
enclosed in HTML bold tags.
Corresponds to the JSON property jobTitleSnippet
1736 1737 1738 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1736 def job_title_snippet @job_title_snippet end |
#search_text_snippet ⇒ String
Contains snippets of text from the Job.description and similar fields that
most closely match a search query's keywords, if available. All HTML tags in
the original fields are stripped when returned in this field, and matching
query keywords are enclosed in HTML bold tags.
Corresponds to the JSON property searchTextSnippet
1744 1745 1746 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1744 def search_text_snippet @search_text_snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/google/apis/jobs_v4/classes.rb', line 1751 def update!(**args) @commute_info = args[:commute_info] if args.key?(:commute_info) @job = args[:job] if args.key?(:job) @job_summary = args[:job_summary] if args.key?(:job_summary) @job_title_snippet = args[:job_title_snippet] if args.key?(:job_title_snippet) @search_text_snippet = args[:search_text_snippet] if args.key?(:search_text_snippet) end |